==> sigma-skeleton-1.1.9.tgz: package/src/providers/data/DataProvider.js <==
import {dataProvider} from './src/config/DataProvider';
import {stringify} from 'query-string';
import {
    fetchUtils,
    GET_LIST,
    GET_ONE,
    GET_MANY,
    GET_MANY_REFERENCE,
    CREATE,
    UPDATE,
    UPDATE_MANY,
    DELETE,
    DELETE_MANY,
} from 'react-admin';

const apiUrl = dataProvider.apiUrl;

class DataProvider {

    constructor() {
        this.httpClient = fetchUtils.fetchJson;
    }

    populateFilters(filters) {
        let filterList = '';

        if (typeof filters !== "object") {
            return filterList;
        }

        for (let key in filters) {

            if (filters.hasOwnProperty(key)) {
                filterList += key + '=' + filters[key];
            }
        }

        return filterList;
    };

    setupOptions(type, params) {
        let options = {};
        options.headers = new Headers({
            'Accept':                      'application/json',
            'Content-Type':                'application/json',
            'Access-Control-Allow-Origin': '*'
        });

        const token = localStorage.getItem('token');
        options.headers.set('Authorization', token);
        options.method = 'GET';

        switch (type) {
            case UPDATE:
                options.method = 'PUT';
                options.body = JSON.stringify(params);
                break;
            case CREATE:
                options.method = 'POST';
                options.body = JSON.stringify(params.data);
                break;
            case DELETE:
                options.method = 'DELETE';
                break;
            default:
                options.method = 'GET';
        }
        return options;
    }

    setupUrl(type, resource, params) {

        let url = '';

        switch (type) {
            case GET_LIST: {
                const {page, perPage} = params.pagination;
                const {field, order} = params.sort;
                const orderBy = 'order[' + field + ']=' + order;
                const filters = this.populateFilters(params.filter);
                const query = {
                    itemsPerPage: perPage,
                    pagination:   true,
                    page:         page,
                };
                url = `${apiUrl}/${resource}?${stringify(query)}&${orderBy}&${filters}`;
                break;
            }
            case GET_ONE:
                url = `${apiUrl}/${resource}/${params.id}`;
                break;
            case GET_MANY: {
                const query = {
                    filter: JSON.stringify({id: params.ids}),
                };
                url = `${apiUrl}/${resource}?${stringify(query)}`;
                break;
            }
            case GET_MANY_REFERENCE: {
                const {page, perPage} = params.pagination;
                const {field, order} = params.sort;
                const query = {
                    sort:   JSON.stringify([field, order]),
                    range:  JSON.stringify([
                        (page - 1) * perPage,
                        page * perPage - 1,
                    ]),
                    filter: JSON.stringify({
                        ...params.filter,
                        [params.target]: params.id,
                    }),
                };
                url = `${apiUrl}/${resource}?${stringify(query)}`;
                break;
            }
            case UPDATE:
                url = `${apiUrl}/${resource}/${params.id}`;
                break;
            case CREATE:
                url = `${apiUrl}/${resource}`;
                break;
            case DELETE:
                url = `${apiUrl}/${resource}/${params.id}`;
                break;
            default:
                throw new Error(`Unsupported fetch action type ${type}`);
        }

        return url;
    }

    convertDataRequestToHTTP(type, resource, params) {
        let url = this.setupUrl(type, resource, params);
        let options = this.setupOptions(type, params);

        return {url, options};
    };

    /**
     * @param {Object} response HTTP response from fetch()
     * @param {String} type One of the constants appearing at the top if this file, e.g. 'UPDATE'
     * @param {String} resource Name of the resource to fetch, e.g. 'posts'
     * @param {Object} params The data request params, depending on the type
     * @returns {Object} Data response
     */
    convertHTTPResponse(response, type, resource, params) {
        const {json} = response;
        switch (type) {
            case GET_LIST:
            case GET_MANY_REFERENCE:
                return {
                    data:  json,
                    total: 1000,
                };
            case CREATE:
                return {data: {...params.data, id: json.id}};
            default:
                return {data: json};
        }
    };

    init() {
        return (type, resource, params) => {
            // simple-rest doesn't handle filters on UPDATE route, so we fallback to calling UPDATE n times instead
            if (type === UPDATE_MANY) {
                return Promise.all(
                    params.ids.map(id =>
                        this.httpClient(`${apiUrl}/${resource}/${id}`, {
                            method: 'PUT',
                            body:   JSON.stringify(params.data),
                        })
                    )
                ).then(responses => ({
                    data: responses.map(response => response.json),
                }));
            }

            // simple-rest doesn't handle filters on DELETE route, so we fallback to calling DELETE n times instead
            if (type === DELETE_MANY) {
                return Promise.all(
                    params.ids.map(id =>
                        this.httpClient(`${apiUrl}/${resource}/${id}`, {
                            method: 'DELETE',
                        })
                    )
                ).then(responses => ({
                    data: responses.map(response => response.json),
                }));
            }

            let {url, options} = this.convertDataRequestToHTTP(type, resource, params);

            return this.httpClient(url, options).then(response => {
                return this.convertHTTPResponse(response, type, resource, params)
            });
        };
    }
}

export default DataProvider;

==> sigma-skeleton-1.1.11.tgz: package/src/providers/data/DataProvider.js <==
import {stringify} from 'query-string';
import {
    fetchUtils,
    GET_LIST,
    GET_ONE,
    GET_MANY,
    GET_MANY_REFERENCE,
    CREATE,
    UPDATE,
    UPDATE_MANY,
    DELETE,
    DELETE_MANY,
} from 'react-admin';



class DataProvider {

    constructor(dataProviderCfg) {
        this.httpClient = fetchUtils.fetchJson;
        const apiUrl = dataProviderCfg.apiUrl;
    }

    populateFilters(filters) {
        let filterList = '';

        if (typeof filters !== "object") {
            return filterList;
        }

        for (let key in filters) {

            if (filters.hasOwnProperty(key)) {
                filterList += key + '=' + filters[key];
            }
        }

        return filterList;
    };

    setupOptions(type, params) {
        let options = {};
        options.headers = new Headers({
            'Accept':                      'application/json',
            'Content-Type':                'application/json',
            'Access-Control-Allow-Origin': '*'
        });

        const token = localStorage.getItem('token');
        options.headers.set('Authorization', token);
        options.method = 'GET';

        switch (type) {
            case UPDATE:
                options.method = 'PUT';
                options.body = JSON.stringify(params);
                break;
            case CREATE:
                options.method = 'POST';
                options.body = JSON.stringify(params.data);
                break;
            case DELETE:
                options.method = 'DELETE';
                break;
            default:
                options.method = 'GET';
        }
        return options;
    }

    setupUrl(type, resource, params) {

        let url = '';

        switch (type) {
            case GET_LIST: {
                const {page, perPage} = params.pagination;
                const {field, order} = params.sort;
                const orderBy = 'order[' + field + ']=' + order;
                const filters = this.populateFilters(params.filter);
                const query = {
                    itemsPerPage: perPage,
                    pagination:   true,
                    page:         page,
                };
                url = `${apiUrl}/${resource}?${stringify(query)}&${orderBy}&${filters}`;
                break;
            }
            case GET_ONE:
                url = `${apiUrl}/${resource}/${params.id}`;
                break;
            case GET_MANY: {
                const query = {
                    filter: JSON.stringify({id: params.ids}),
                };
                url = `${apiUrl}/${resource}?${stringify(query)}`;
                break;
            }
            case GET_MANY_REFERENCE: {
                const {page, perPage} = params.pagination;
                const {field, order} = params.sort;
                const query = {
                    sort:   JSON.stringify([field, order]),
                    range:  JSON.stringify([
                        (page - 1) * perPage,
                        page * perPage - 1,
                    ]),
                    filter: JSON.stringify({
                        ...params.filter,
                        [params.target]: params.id,
                    }),
                };
                url = `${apiUrl}/${resource}?${stringify(query)}`;
                break;
            }
            case UPDATE:
                url = `${apiUrl}/${resource}/${params.id}`;
                break;
            case CREATE:
                url = `${apiUrl}/${resource}`;
                break;
            case DELETE:
                url = `${apiUrl}/${resource}/${params.id}`;
                break;
            default:
                throw new Error(`Unsupported fetch action type ${type}`);
        }

        return url;
    }

    convertDataRequestToHTTP(type, resource, params) {
        let url = this.setupUrl(type, resource, params);
        let options = this.setupOptions(type, params);

        return {url, options};
    };

    /**
     * @param {Object} response HTTP response from fetch()
     * @param {String} type One of the constants appearing at the top if this file, e.g. 'UPDATE'
     * @param {String} resource Name of the resource to fetch, e.g. 'posts'
     * @param {Object} params The data request params, depending on the type
     * @returns {Object} Data response
     */
    convertHTTPResponse(response, type, resource, params) {
        const {json} = response;
        switch (type) {
            case GET_LIST:
            case GET_MANY_REFERENCE:
                return {
                    data:  json,
                    total: 1000,
                };
            case CREATE:
                return {data: {...params.data, id: json.id}};
            default:
                return {data: json};
        }
    };

    init() {
        return (type, resource, params) => {
            // simple-rest doesn't handle filters on UPDATE route, so we fallback to calling UPDATE n times instead
            if (type === UPDATE_MANY) {
                return Promise.all(
                    params.ids.map(id =>
                        this.httpClient(`${apiUrl}/${resource}/${id}`, {
                            method: 'PUT',
                            body:   JSON.stringify(params.data),
                        })
                    )
                ).then(responses => ({
                    data: responses.map(response => response.json),
                }));
            }

            // simple-rest doesn't handle filters on DELETE route, so we fallback to calling DELETE n times instead
            if (type === DELETE_MANY) {
                return Promise.all(
                    params.ids.map(id =>
                        this.httpClient(`${apiUrl}/${resource}/${id}`, {
                            method: 'DELETE',
                        })
                    )
                ).then(responses => ({
                    data: responses.map(response => response.json),
                }));
            }

            let {url, options} = this.convertDataRequestToHTTP(type, resource, params);

            return this.httpClient(url, options).then(response => {
                return this.convertHTTPResponse(response, type, resource, params)
            });
        };
    }
}

export default DataProvider;
